import React from 'react'
import { css } from 'glamor'
import cx from 'classnames'
import Box from './Box'
import SearchIcon from './SearchIcon'
import theme from './theme'
import splitProps from '../utils/splitProps'
const { minorScale, majorScale } = theme

const styles = css({
  color: theme.backgrounds.white.textColor,
  boxShadow: `inset 0 0 0 1px ${theme.backgrounds.white.borderColor}`,
  '&:focus, &:active': {
    boxShadow: `inset 0 0 0 1px ${theme.colors.primary}`
  }
})

const SearchInput = ({ className, ...props }) => {
  // Tries to treat this component as a single box
  const { matchedProps, unmatchedProps } = splitProps(props,
    /margin|width|height|display/gi)

  return (
    <Box position='relative' display='flex' {...matchedProps}>
      <SearchIcon style={{ pointerEvents: 'none' }} size='small' position='absolute' top='50%' marginLeft={minorScale(3)} marginTop={majorScale(-1)} />
      <Box is='input' className={cx(`${styles}`, className)} flex='1' {...unmatchedProps} />
    </Box>
  )
}

SearchInput.defaultProps = {
  circle: true,
  paddingX: majorScale(2),
  paddingLeft: majorScale(5),
  paddingY: majorScale(1),
  textStyle: 'body1'
}

SearchInput.displayName = 'SearchInput'

export default SearchInput
