import React from 'react'
import { storiesOf } from '@kadira/storybook'
import {
  App,
  Select,
  Pane,
  Content,
  theme
} from '../components'
const { majorScale } = theme

export default function selectStory (module) {
  storiesOf('Select', module)
    .add('usage', () => (
      <App white>
        <Pane white padding={majorScale(10)}>
          <Content markdown>
            {`
# Select

The Select component is a \`select\` element. Implement the \`<Box />\` component.

You can use the Select component in 2 ways:

## 1. Pass in options directly

\`\`\`
<Select>
  <option value="grapefruit">Grapefruit</option>
  <option value="lime">Lime</option>
  <option value="coconut">Coconut</option>
  <option value="mango">Mango</option>
</Select>
\`\`\`

`}
          </Content>
          <Select>
            <option value='grapefruit'>Grapefruit</option>
            <option value='lime'>Lime</option>
            <option value='coconut'>Coconut</option>
            <option value='mango'>Mango</option>
          </Select>
          <Content markdown>
            {`

## 2. Pass in options as an object through an \`options\` prop

This is the same API as in @segment/react-forms SelectField.

\`\`\`
<Select options={[
    {
      label: 'Grapefruit',
      value: 'grapefruit'
    },
    {
      label: 'Lime',
      value: 'lime'
    },
    {
      label: 'Coconut',
      value: 'coconut'
    }
  ]} />
\`\`\`

        `}
          </Content>
          <Select options={[
            {
              label: 'Grapefruit',
              value: 'grapefruit'
            },
            {
              label: 'Lime',
              value: 'lime'
            },
            {
              label: 'Coconut',
              value: 'coconut'
            }
          ]} />
          <Content markdown>
            {`

## 3. Pass in options as a string through an \`options\` prop

This is the same API as in @segment/react-forms SelectField.

\`\`\`
<Select options={['Grapefruit','Lime', 'Coconut']} />
\`\`\`

        `}
          </Content>
          <Select options={['Grapefruit', 'Lime', 'Coconut']} />
          <Content markdown>
            {`
  prop | type | default | description
  -----|------| --------|-------------
  \`options\` | [String] / [{ label: String, value: String }] | undefined | replaces children
        `}
          </Content>
        </Pane>
      </App>
    ))
    .add('standalone', () => (
      <Select>
        <option value='grapefruit'>Grapefruit</option>
        <option value='lime'>Lime</option>
        <option value='coconut'>Coconut</option>
        <option value='mango'>Mango</option>
      </Select>
    ))
    .add('with spacing', () => (
      <Pane white>
        <Select marginX={3}>
          <option value='grapefruit'>Grapefruit</option>
          <option value='lime'>Lime</option>
          <option value='coconut'>Coconut</option>
          <option value='mango'>Mango</option>
        </Select>
      </Pane>
    ))
    .add('with width and centered', () => (
      <Pane white clearfix>
        <Select width='240px' marginX='auto' marginY={majorScale(10)}>
          <option value='grapefruit'>Grapefruit</option>
          <option value='lime'>Lime</option>
          <option value='coconut'>Coconut</option>
          <option value='mango'>Mango</option>
        </Select>
      </Pane>
    ))
}
